## Package Pikobs ##

Observation evaluation tools 

# Capabilities #

This Python package Pikobs provides the following capabilities:

 
 
*  [`Cardiogram`](https://gitlab.science.gc.ca/dlo001/Pikobs/-/blob/master/readme/readme_cardiograme.md)

*  Radiance Space Verification

*  Time Series

*  Profiles

*  Histograms

*  Scatter Plots

*  Installation

# Basic instructions to install  the package #


`pip install pikobs`
